{% extends "contact_form/base.html" %}

{% load i18n %}

{% load bootstrap %}

{% block page_title %}{% trans "Contact Us" %}{% endblock %}

{% block content %}
<h1>{% trans "Contact Us" %}</h1>

<form class="login form-horizontal" method="POST" action="{% url 'feedback:contact_form' %}">
  {% csrf_token %}
  {{ form|bootstrap_horizontal }}
  <div class="form-actions">
    <button class="btn btn-primary" type="submit">{% trans "Send message" %}</button>
  </div>
</form>
{% endblock %}
